"""Python bindings for Django Mercury."""

# Note: pure_python.py has been removed as it was dead code.
# All functionality is now in monitor.py which uses Django/Python stdlib directly.

__all__ = []
